Vault
-----

.. autosimple:: swh.web.vault.api_views.api_vault_cook_flat

.. autosimple:: swh.web.vault.api_views.api_vault_download_flat

.. autosimple:: swh.web.vault.api_views.api_vault_cook_git_bare

.. autosimple:: swh.web.vault.api_views.api_vault_download_revision_git_bare

.. autosimple:: swh.web.vault.api_views.api_vault_cook_gitfast

.. autosimple:: swh.web.vault.api_views.api_vault_download_revision_gitfast

.. autosimple:: swh.web.vault.api_views.api_vault_cook_directory

.. autosimple:: swh.web.vault.api_views.api_vault_download_directory

.. autosimple:: swh.web.vault.api_views.api_vault_cook_revision_gitfast


